# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetMeetingRoomRoomIDReq(object):
    custom_room_ids: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于查询指定会议室的租户自定义会议室ID


@attr.s
class BatchGetMeetingRoomRoomIDRespRoom(object):
    room_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室 ID
    custom_room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户自定义会议室 ID


@attr.s
class BatchGetMeetingRoomRoomIDResp(object):
    rooms: BatchGetMeetingRoomRoomIDRespRoom = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 会议室列表


def _gen_batch_get_meeting_room_room_id_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetMeetingRoomRoomIDResp,
        scope="MeetingRoom",
        api="BatchGetMeetingRoomRoomID",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/room/batch_get_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
