# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteMailGroupMemberReq(object):
    mailgroup_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # The unique ID or email address of a mail group, 示例值："xxxxxxxxxxxxxxx or test_mail_group@xxx.xx"
    member_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # The unique ID of a member in this mail group, 示例值："xxxxxxxxxxxxxxx"


@attr.s
class DeleteMailGroupMemberResp(object):
    pass


def _gen_delete_mail_group_member_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteMailGroupMemberResp,
        scope="Mail",
        api="DeleteMailGroupMember",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/mail/v1/mailgroups/:mailgroup_id/members/:member_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
