# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_admin_admin_dept_stats_get import (
    GetAdminDeptStatsReq,
    GetAdminDeptStatsResp,
    _gen_get_admin_dept_stats_req,
)
from pylark.api_service_admin_admin_user_stats_get import (
    GetAdminUserStatsReq,
    GetAdminUserStatsResp,
    _gen_get_admin_user_stats_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkAdminService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_admin_dept_stats(
        self, request: GetAdminDeptStatsReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAdminDeptStatsResp, Response]:
        return self.cli.raw_request(_gen_get_admin_dept_stats_req(request, options))

    def get_admin_user_stats(
        self, request: GetAdminUserStatsReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAdminUserStatsResp, Response]:
        return self.cli.raw_request(_gen_get_admin_user_stats_req(request, options))
