# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteAttendanceGroupReq(object):
    group_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 考勤组的 ID，需要从获取打卡结果的接口中获取 group_id，示例值："6919358128597097404"


@attr.s
class DeleteAttendanceGroupResp(object):
    pass


def _gen_delete_attendance_group_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteAttendanceGroupResp,
        scope="Attendance",
        api="DeleteAttendanceGroup",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/attendance/v1/groups/:group_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
