# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateDriveFileReq(object):
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件夹 token，用于在此文件夹下新建文档，获取方式见[概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要创建文档的类型  "doc" 、 "sheet"  or  "bitable"
    title: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 创建文档的标题。注：type 为 "doc" 时不可用（非必填，请求会被过滤），有创建带标题doc文档需求可用 [创建文档](https://open.feishu.cn/document/ukTMukTMukTM/ugDM2YjL4AjN24COwYjN) 接口


@attr.s
class CreateDriveFileResp(object):
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文档的 url
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # 新创建文档的版本号


def _gen_create_drive_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateDriveFileResp,
        scope="Drive",
        api="CreateDriveFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/file/:folderToken",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
