# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteSheetFloatImageReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 表格 token, 示例值："shtcnmBA*****yGehy8"
    sheet_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 子表 id, 示例值："0b**12"
    float_image_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 浮动图片 id, 示例值："ye06SS14ph"


@attr.s
class DeleteSheetFloatImageResp(object):
    pass


def _gen_delete_sheet_float_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteSheetFloatImageResp,
        scope="Drive",
        api="DeleteSheetFloatImage",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets/:spreadsheet_token/sheets/:sheet_id/float_images/:float_image_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
