# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteMessageReq(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 待撤回的消息的ID, 示例值："om_dc13264520392913993dd051dba21dcf"


@attr.s
class DeleteMessageResp(object):
    pass


def _gen_delete_message_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteMessageResp,
        scope="Message",
        api="DeleteMessage",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/im/v1/messages/:message_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
