# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenCalenderEventCreateReq(object):
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始日期，{unixTime}格式
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束日期，{unixTime}格式
    summary: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日程主题，中文可使用encodeURIComponent方法生成


@attr.s
class OpenCalenderEventCreateResp(object):
    pass


def _gen_open_calender_event_create_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenCalenderEventCreateResp,
        scope="AppLink",
        api="OpenCalenderEventCreate",
        method="",
        url="https://applink.feishu.cn/client/calendar/event/create",
        body=request,
        method_option=_new_method_option(options),
    )
