# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetMeetingRoomBuildingIDReq(object):
    custom_building_ids: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于查询指定建筑物的租户自定义建筑ID


@attr.s
class BatchGetMeetingRoomBuildingIDRespBuilding(object):
    building_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑物ID
    custom_building_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户自定义建筑物ID


@attr.s
class BatchGetMeetingRoomBuildingIDResp(object):
    buildings: BatchGetMeetingRoomBuildingIDRespBuilding = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 建筑列表


def _gen_batch_get_meeting_room_building_id_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetMeetingRoomBuildingIDResp,
        scope="MeetingRoom",
        api="BatchGetMeetingRoomBuildingID",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/building/batch_get_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
