# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_bot_info import (
    GetBotInfoReq,
    GetBotInfoResp,
    _gen_get_bot_info_req,
)
from pylark.api_service_bot_add import (
    AddBotToChatReq,
    AddBotToChatResp,
    _gen_add_bot_to_chat_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkBotService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_bot_info(
        self, request: GetBotInfoReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetBotInfoResp, Response]:
        return self.cli.raw_request(_gen_get_bot_info_req(request, options))

    def add_bot_to_chat(
        self, request: AddBotToChatReq, options: typing.List[str] = None
    ) -> typing.Tuple[AddBotToChatResp, Response]:
        return self.cli.raw_request(_gen_add_bot_to_chat_req(request, options))
