# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class IsInChatReq(object):
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 群 ID, 示例值: "oc_a0553eda9014c201e6969b478895c230"


@attr.s
class IsInChatResp(object):
    is_in_chat: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 用户或者机器人是否在群中


def _gen_is_in_chat_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=IsInChatResp,
        scope="Chat",
        api="IsInChat",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/chats/:chat_id/members/is_in_chat",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
