# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveRootFolderMetaReq(object):
    pass


@attr.s
class GetDriveRootFolderMetaResp(object):
    token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的 token
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的 id
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的所有者 id


def _gen_get_drive_root_folder_meta_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveRootFolderMetaResp,
        scope="Drive",
        api="GetDriveRootFolderMeta",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/root_folder/meta",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
