# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMeetingRoomCountryListReq(object):
    pass


@attr.s
class GetMeetingRoomCountryListRespCountries(object):
    country_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 国家地区ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 国家地区名称


@attr.s
class GetMeetingRoomCountryListResp(object):
    countries: GetMeetingRoomCountryListRespCountries = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 国家地区列表


def _gen_get_meeting_room_country_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMeetingRoomCountryListResp,
        scope="MeetingRoom",
        api="GetMeetingRoomCountryList",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/country/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
