# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteHelpdeskAgentSkillReq(object):
    agent_skill_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # agent group id, 示例值："test-skill-id"


@attr.s
class DeleteHelpdeskAgentSkillResp(object):
    pass


def _gen_delete_helpdesk_agent_skill_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteHelpdeskAgentSkillResp,
        scope="Helpdesk",
        api="DeleteHelpdeskAgentSkill",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agent_skills/:agent_skill_id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )
