# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenCalenderViewReq(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 视图类型，枚举值包括：<br> `day`：日视图 <br>`three_day`：三日视图，仅移动端支持<br> `week`：周视图，仅PC端支持 <br>  `month`：月视图<br> `meeting`：会议室视图，仅PC端支持 <br> `list`：列表视图，仅移动端支持
    date: str = attr.ib(default="", metadata={"req_type": "json"})  # 日期，{unixTime}格式


@attr.s
class OpenCalenderViewResp(object):
    pass


def _gen_open_calender_view_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenCalenderViewResp,
        scope="AppLink",
        api="OpenCalenderView",
        method="",
        url="https://applink.feishu.cn/client/calendar/view",
        body=request,
        method_option=_new_method_option(options),
    )
