# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateHireApplicationReq(object):
    talent_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 人才ID, 示例值："12312312312"
    job_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 职位ID, 示例值："12312312312"


@attr.s
class CreateHireApplicationResp(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 投递ID


def _gen_create_hire_application_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateHireApplicationResp,
        scope="Hire",
        api="CreateHireApplication",
        method="POST",
        url="https://open.feishu.cn/open-apis/hire/v1/applications",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
