# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskAgentEmailReq(object):
    pass


@attr.s
class GetHelpdeskAgentEmailResp(object):
    agents: str = attr.ib(default="", metadata={"req_type": "json"})  # agent emails


def _gen_get_helpdesk_agent_email_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskAgentEmailResp,
        scope="Helpdesk",
        api="GetHelpdeskAgentEmail",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agent_emails",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )
