# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateMeetingRoomBuildingReq(object):
    building_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 要更新的建筑ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑名称
    floors: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 楼层列表
    country_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 国家/地区ID
    district_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 城市ID
    custom_building_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户自定义建筑ID


@attr.s
class UpdateMeetingRoomBuildingResp(object):
    pass


def _gen_update_meeting_room_building_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateMeetingRoomBuildingResp,
        scope="MeetingRoom",
        api="UpdateMeetingRoomBuilding",
        method="POST",
        url="https://open.feishu.cn/open-apis/meeting_room/building/update",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
