# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateDriveCommentPatchReqFileType(object):
    pass


@attr.s
class UpdateDriveCommentPatchReq(object):
    file_type: UpdateDriveCommentPatchReqFileType = attr.ib(
        factory=lambda: UpdateDriveCommentPatchReqFileType(),
        metadata={"req_type": "query"},
    )  # 文档类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：表格, `file`：文件
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文档token, 示例值："doccnGp4UK1UskrOEJwBXd3****"
    comment_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 评论ID, 示例值："6916106822734578184"
    is_solved: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 评论解决标志, 示例值：true


@attr.s
class UpdateDriveCommentPatchResp(object):
    pass


def _gen_update_drive_comment_patch_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateDriveCommentPatchResp,
        scope="Drive",
        api="UpdateDriveCommentPatch",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/drive/v1/files/:file_token/comments/:comment_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
