# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteHelpdeskTicketCustomizedFieldReq(object):
    ticket_customized_field_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 工单自定义字段ID, 示例值："6948728206392295444"


@attr.s
class DeleteHelpdeskTicketCustomizedFieldResp(object):
    pass


def _gen_delete_helpdesk_ticket_customized_field_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteHelpdeskTicketCustomizedFieldResp,
        scope="Helpdesk",
        api="DeleteHelpdeskTicketCustomizedField",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/ticket_customized_fields/:ticket_customized_field_id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )
