# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateEmployeeTypeEnumReqI18nContent(object):
    locale: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言, 示例值："zh_cn"
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # i18n内容, 示例值："专家"


@attr.s
class CreateEmployeeTypeEnumReq(object):
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 枚举内容, 示例值："专家", 长度范围：`1` ～ `100` 字符
    enum_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 示例值：2, 可选值有: `1`：内置类型, `2`：自定义
    enum_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 示例值：1, 可选值有: `1`：激活, `2`：未激活
    i18n_content: CreateEmployeeTypeEnumReqI18nContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # i18n定义


@attr.s
class CreateEmployeeTypeEnumRespEmployeeTypeEnumI18nContent(object):
    locale: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # i18n内容


@attr.s
class CreateEmployeeTypeEnumRespEmployeeTypeEnum(object):
    enum_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 枚举值id
    enum_value: str = attr.ib(default="", metadata={"req_type": "json"})  # 枚举值
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 枚举内容, 长度范围：`1` ～ `100` 字符
    enum_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 可选值有: `1`：内置类型, `2`：自定义
    enum_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 可选值有: `1`：激活, `2`：未激活
    i18n_content: CreateEmployeeTypeEnumRespEmployeeTypeEnumI18nContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # i18n定义


@attr.s
class CreateEmployeeTypeEnumResp(object):
    employee_type_enum: CreateEmployeeTypeEnumRespEmployeeTypeEnum = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 新建的人员类型信息


def _gen_create_employee_type_enum_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateEmployeeTypeEnumResp,
        scope="Contact",
        api="CreateEmployeeTypeEnum",
        method="POST",
        url="https://open.feishu.cn/open-apis/contact/v3/employee_type_enums",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
