# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenSSOLoginReq(object):
    sso_domain: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户的域名，填写的是租户在admin后台配置的租户域名信息。当在admin后台改动租户的域名时，需要同步修改applink该参数值
    tenant_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户名，用于在切换租户时，客户端展示即将登录到的租户名称，一般填写公司名即可


@attr.s
class OpenSSOLoginResp(object):
    pass


def _gen_open_sso_login_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenSSOLoginResp,
        scope="AppLink",
        api="OpenSSOLogin",
        method="",
        url="https://applink.feishu.cn/client/passport/sso_login",
        body=request,
        method_option=_new_method_option(options),
    )
