# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenWebURLReq(object):
    url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 指定需要在客户端内打开的具体链接，需要执行encodeURIComponent，4.2+版本支持lark协议
    mode: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打开的容器模式，枚举值包括：<br>`sidebar-semi` 在侧边栏打开；<br>`window` 在独立窗口打开
    height: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义独立窗口高度
    width: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义独立窗口宽度


@attr.s
class OpenWebURLResp(object):
    pass


def _gen_open_web_url_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenWebURLResp,
        scope="AppLink",
        api="OpenWebURL",
        method="",
        url="https://applink.feishu.cn/client/web_url/open",
        body=request,
        method_option=_new_method_option(options),
    )
