# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CopyDriveFileReq(object):
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 需要复制的源文件或文档的 token, 获取方式见 [概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要创建文档的类型   "doc" 、"sheet" or "bitable"
    dst_folder_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 目标文件夹的 token, 获取方式见 [概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)
    dst_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 复制的副本文件的新名称
    comment_needed: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否复制评论


@attr.s
class CopyDriveFileResp(object):
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 目标文件夹的 token
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # 新创建文档的版本号
    token: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文档的 token
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 新建文档的类型，"doc" or "sheet"
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文档的 url


def _gen_copy_drive_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CopyDriveFileResp,
        scope="Drive",
        api="CopyDriveFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/file/copy/files/:fileToken",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
