# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_ehr_employee_get_list import (
    GetEHREmployeeListReq,
    GetEHREmployeeListResp,
    _gen_get_ehr_employee_list_req,
)
from pylark.api_service_ehr_download_attachment import (
    DownloadEHRAttachmentsReq,
    DownloadEHRAttachmentsResp,
    _gen_download_ehr_attachments_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkEHRService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_ehr_employee_list(
        self, request: GetEHREmployeeListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetEHREmployeeListResp, Response]:
        return self.cli.raw_request(_gen_get_ehr_employee_list_req(request, options))

    def download_ehr_attachments(
        self, request: DownloadEHRAttachmentsReq, options: typing.List[str] = None
    ) -> typing.Tuple[DownloadEHRAttachmentsResp, Response]:
        return self.cli.raw_request(_gen_download_ehr_attachments_req(request, options))
