# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateMessageReq(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 待更新的消息的ID, 示例值："om_dc13264520392913993dd051dba21dcf"
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息内容 json 格式，[发送消息 content 说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/im-v1/message/create_json)，参考文档中的卡片格式|, 示例值："参考链接"


@attr.s
class UpdateMessageResp(object):
    pass


def _gen_update_message_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateMessageResp,
        scope="Message",
        api="UpdateMessage",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/im/v1/messages/:message_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
