# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskAgentSkillListReq(object):
    pass


@attr.s
class GetHelpdeskAgentSkillListRespAgentSkill(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 技能id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 技能名
    agent_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 具有此技能的客服ids
    is_default: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 默认技能


@attr.s
class GetHelpdeskAgentSkillListResp(object):
    agent_skills: typing.List[GetHelpdeskAgentSkillListRespAgentSkill] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 客服技能列表


def _gen_get_helpdesk_agent_skill_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskAgentSkillListResp,
        scope="Helpdesk",
        api="GetHelpdeskAgentSkillList",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agent_skills",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )
