# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteVCReserveReq(object):
    reserve_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 预约ID（预约的唯一标识）, 示例值："6911188411932033028"


@attr.s
class DeleteVCReserveResp(object):
    pass


def _gen_delete_vc_reserve_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteVCReserveResp,
        scope="VC",
        api="DeleteVCReserve",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/vc/v1/reserves/:reserve_id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )
