# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateMeetingRoomRoomReq(object):
    building_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室所在的建筑ID
    floor: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室所在的建筑楼层
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室名称
    capacity: int = attr.ib(default=0, metadata={"req_type": "json"})  # 容量
    is_disabled: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否禁用
    custom_room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户自定义会议室ID


@attr.s
class CreateMeetingRoomRoomResp(object):
    room_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 成功创建的会议室ID


def _gen_create_meeting_room_room_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateMeetingRoomRoomResp,
        scope="MeetingRoom",
        api="CreateMeetingRoomRoom",
        method="POST",
        url="https://open.feishu.cn/open-apis/meeting_room/room/create",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
