# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveDocRawContentReq(object):
    doc_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 获取方式详见 [准备接入文档 API](https://open.feishu.cn/document/ukTMukTMukTM/ugzNzUjL4czM14CO3MTN/guide/getting-start)


@attr.s
class GetDriveDocRawContentResp(object):
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 如: string


def _gen_get_drive_doc_raw_content_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveDocRawContentResp,
        scope="Drive",
        api="GetDriveDocRawContent",
        method="GET",
        url="https://open.feishu.cn/open-apis/doc/v2/:docToken/raw_content",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
