# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteHelpdeskFAQReq(object):
    id: str = attr.ib(default="", metadata={"req_type": "path"})  # id, 示例值："12345"


@attr.s
class DeleteHelpdeskFAQResp(object):
    pass


def _gen_delete_helpdesk_faq_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteHelpdeskFAQResp,
        scope="Helpdesk",
        api="DeleteHelpdeskFAQ",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/faqs/:id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )
