# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteCalendarACLReq(object):
    calendar_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日历ID, 示例值："feishu.cn_xxxxxxxxxx@group.calendar.feishu.cn"
    acl_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # acl资源ID, 示例值："user_xxxxxx"


@attr.s
class DeleteCalendarACLResp(object):
    pass


def _gen_delete_calendar_acl_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteCalendarACLResp,
        scope="Calendar",
        api="DeleteCalendarACL",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/:calendar_id/acls/:acl_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
