# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMeetingRoomDistrictListReq(object):
    country_id: int = attr.ib(default=0, metadata={"req_type": "query"})  # 国家地区ID


@attr.s
class GetMeetingRoomDistrictListRespDistricts(object):
    district_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 城市ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 城市名称


@attr.s
class GetMeetingRoomDistrictListResp(object):
    districts: GetMeetingRoomDistrictListRespDistricts = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 城市列表


def _gen_get_meeting_room_district_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMeetingRoomDistrictListResp,
        scope="MeetingRoom",
        api="GetMeetingRoomDistrictList",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/district/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
